import os
import pygame
import time
MODULE_PATH = os.path.dirname(__file__)
AUDIO_DIR = os.path.join(MODULE_PATH)

pygame.mixer.init()
def Lettre ():
    pygame.mixer.music.load(os.path.join(AUDIO_DIR, "sound/lettre.wav"))
    pygame.mixer.music.play()
    time.sleep(0.05)
def Point ():
    pygame.mixer.music.load(os.path.join(AUDIO_DIR, "sound/point.wav"))
    pygame.mixer.music.play()
    time.sleep(0.1)
def Espace ():
    pygame.mixer.music.load(os.path.join(AUDIO_DIR, "sound/espace.wav"))
    pygame.mixer.music.play()
    time.sleep(0.05)


import sys
from .Sound import Point
from .Sound import Lettre
from .Sound import Espace

ponctuation = [".", "!", ";", "?", "«", "»", "-", "'", "(", ")"]
#from playsound import playsound
#from pydub import AudioSegment
#from pydub.playback import play
def defileSound (*x):
    for phrase in x:
        #sys.stdout.write("[phrase = " + phrase + "]\n")
        for i in phrase :
            #sys.stdout.write("i = " + i + "\n")
            sys.stdout.write(i)
            sys.stdout.flush()
            if i in ponctuation :
                Point()
            elif i == " ":
                Espace()        
            else :
                Lettre()


import time
import sys
#a = 8
"""                                                 UTILISATION
Importez le module texte. Puis utilisez l'option défilement avec la ligne text.défile("ce que vous voulez")
ATTENTION : si vous voulez utilisez une variable float ou int, vous devez utilisez str(variable), example: texte.défilement("il y a", str(variable))"""
"""                                                     USE
Import the text module. Then use the Scroll option with the line of code text.defile ("what you want")
WARNING: If you want to use a float variable or int, you must use str(variable), example: text.defile ("There is", str(variable))
"""
def defile (*x):
    for phrase in x:
        #sys.stdout.write("[phrase = " + phrase + "]\n")
        for i in phrase :
            #sys.stdout.write("i = " + i + "\n")
            sys.stdout.write(i)
            sys.stdout.flush()
            time.sleep(0.05)




import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="TextEdit",
    version="1.2.1",
    author="Corentin Perdry",
    author_email="corentin.perdry@gmail.com",
    description="A small module for to display the letters at the sequence.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/C0rent1Perdry/TextEdit-1.0",
    project_urls={
        "Bug Tracker": "https://github.com/C0rent1Perdry/TextEdit-1.0/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=setuptools.find_packages(),
    include_package_data=True,
    package_data={'': ['sound/*.wav']},
    python_requires=">=3.6",
)